==> qiho-center-api-1.0.3-sources.jar: com/qiho/center/api/params/OrderPageParams.java <==
package com.qiho.center.api.params;

import java.util.Date;

/**
 * Created by liuyao on 2017/6/2.
 * 全部订单检索分页封装
 */
public class OrderPageParams extends PageQueryParams{

    private String orderId;

    private Long itemId;
    private String itemName;
    private String itemNo;
    private String skuNo;

    private String postId;
    private String consumerName;
    private String mobile;

    private Date startTime;
    private Date endTime;
    private String orderStatus;

    private String delivery;
    private String channelId;
    private String countChannelId;

    public String getOrderId() {
        return orderId;
    }

    public void setOrderId(String orderId) {
        this.orderId = orderId;
    }

    public Long getItemId() {
        return itemId;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public String getItemName() {
        return itemName;
    }

    public void setItemName(String itemName) {
        this.itemName = itemName;
    }

    public String getItemNo() {
        return itemNo;
    }

    public void setItemNo(String itemNo) {
        this.itemNo = itemNo;
    }

    public String getSkuNo() {
        return skuNo;
    }

    public void setSkuNo(String skuNo) {
        this.skuNo = skuNo;
    }

    public String getPostId() {
        return postId;
    }

    public void setPostId(String postId) {
        this.postId = postId;
    }

    public String getConsumerName() {
        return consumerName;
    }

    public void setConsumerName(String consumerName) {
        this.consumerName = consumerName;
    }

    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public String getOrderStatus() {
        return orderStatus;
    }

    public void setOrderStatus(String orderStatus) {
        this.orderStatus = orderStatus;
    }

    public String getDelivery() {
        return delivery;
    }

    public void setDelivery(String delivery) {
        this.delivery = delivery;
    }

    public String getChannelId() {
        return channelId;
    }

    public void setChannelId(String channelId) {
        this.channelId = channelId;
    }

    public String getCountChannelId() {
        return countChannelId;
    }

    public void setCountChannelId(String countChannelId) {
        this.countChannelId = countChannelId;
    }
}

==> qiho-center-api-1.7.3-sources.jar: com/qiho/center/api/params/OrderPageParams.java <==
package com.qiho.center.api.params;

import java.util.Date;

/**
 * Created by liuyao on 2017/6/2.
 * 全部订单检索分页封装
 */
public class OrderPageParams extends PageQueryParams{

    private String orderId;

    private Long itemId;
    private String itemName;
    private String itemNo;
    private String skuNo;

    private String postId;
    private String consumerName;
    private String mobile;
    private Long merchantId;

    private Date startTime;
    private Date endTime;
    private String orderStatus;

    private String delivery;
    private String channelId;
    private String countChannelId;
    private String tuiaId;

    private String orderProcessWay;
    private Date processTime;


    public String getOrderId() {
        return orderId;
    }

    public void setOrderId(String orderId) {
        this.orderId = orderId;
    }

    public Long getItemId() {
        return itemId;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public String getItemName() {
        return itemName;
    }

    public void setItemName(String itemName) {
        this.itemName = itemName;
    }

    public String getItemNo() {
        return itemNo;
    }

    public void setItemNo(String itemNo) {
        this.itemNo = itemNo;
    }

    public String getSkuNo() {
        return skuNo;
    }

    public void setSkuNo(String skuNo) {
        this.skuNo = skuNo;
    }

    public String getPostId() {
        return postId;
    }

    public void setPostId(String postId) {
        this.postId = postId;
    }

    public String getConsumerName() {
        return consumerName;
    }

    public void setConsumerName(String consumerName) {
        this.consumerName = consumerName;
    }

    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public String getOrderStatus() {
        return orderStatus;
    }

    public void setOrderStatus(String orderStatus) {
        this.orderStatus = orderStatus;
    }

    public String getDelivery() {
        return delivery;
    }

    public void setDelivery(String delivery) {
        this.delivery = delivery;
    }

    public String getChannelId() {
        return channelId;
    }

    public void setChannelId(String channelId) {
        this.channelId = channelId;
    }

    public String getCountChannelId() {
        return countChannelId;
    }

    public void setCountChannelId(String countChannelId) {
        this.countChannelId = countChannelId;
    }

    public String getTuiaId() {
        return tuiaId;
    }

    public void setTuiaId(String tuiaId) {
        this.tuiaId = tuiaId;
    }

    public String getOrderProcessWay() {
        return orderProcessWay;
    }

    public void setOrderProcessWay(String orderProcessWay) {
        this.orderProcessWay = orderProcessWay;
    }

    public Date getProcessTime() {
        return processTime;
    }

    public void setProcessTime(Date processTime) {
        this.processTime = processTime;
    }

    public Long getMerchantId() {
        return merchantId;
    }

    public void setMerchantId(Long merchantId) {
        this.merchantId = merchantId;
    }
}
